@@ -11,6 +11,8 @@ from marshmallow import Schema
 from marshmallow import post_load
 from enum import Enum as ENUM
 from .order_item import OrderItemSchema
+from .shipping_method import ShippingMethodSchema
+from .payment_method import PaymentMethodSchema
 from marshmallow_enum import EnumField
 
 from .base import Base
@@ -31,7 +33,7 @@ class Order(Base):
     order_number = Column(String(25), nullable=False, unique=True)
     user_id = Column(ForeignKey('users.id'), nullable=False, server_default='78')
     order_date = Column(DateTime, nullable=False, server_default=func.now())
-    updated_date = Column(DateTime, nullable=True, server_onupdate=func.now())
+    updated_date = Column(DateTime, nullable=True, onupdate=func.now())
     status = Column(Enum(OrderStatus), nullable=False)
     contact_email = Column(String(30), nullable=False)
     contact_phone = Column(String(15), nullable=False)
@@ -50,6 +52,8 @@ class Order(Base):
     payment_method = Column(ForeignKey('payment_methods.id'), nullable=False)
 
     order_items = relationship('OrderItem', primaryjoin='Order.id == OrderItem.order_id')
+    shipping = relationship('ShippingMethod', primaryjoin='Order.shipping_method == ShippingMethod.id')
+    payment = relationship('PaymentMethod', primaryjoin='Order.payment_method == PaymentMethod.id')
 
 
 class OrderSchema(Schema):
@@ -79,6 +83,8 @@ class OrderSchema(Schema):
     payment_method = fields.Integer(data_key='paymentMethod')
 
     order_items = fields.Nested(OrderItemSchema, many=True, data_key='orderItems')
+    shipping = fields.Nested(ShippingMethodSchema, many=False)
+    payment = fields.Nested(PaymentMethodSchema, many=False)
 
     @post_load
     def make_address(self, data, **kwargs):
